      SUBROUTINE ALPHA(PRSDB,RHO,ALPH,DELTA)
C
C     TITLE:
C     *****
C
C       ALPHA  -- CALCULATE RHO, SPECIFIC VOLUME(ALPHA),
C                 SPECIFIC VOLUME ANOMALY (DELTA)
C
C     SYSTEM:
C     ******
C
C       PACODF HYDROGRAPHIC DATA LIBRARY
C
C     PURPOSE:
C     *******
C
C       TO CALCULATE SPECIFIC VOLUME AND SPECIFIC VOLUME ANOMALY
C
C     METHOD:
C     ******
C
C       ALPHA = 1/RHO,
C       DELTA = ALPHA-RHO(P,0,35)
C
C     MACHINE-DEPENDENCIES:
C     ********************
C
C        *** NONE ***
C
C     NON-ANSI EXTENSIONS:
C     *******************
C
C        *** NONE ***
C
C     EXTERNAL DATA SETS:
C     ******** **** ****
C
C        *** NONE ***
C
C     EXTERNAL REFERENCES:
C     ******** **********
C
C       SIGMP  -- CALCULATE DENSITY
C
C     FUNCTION DECLARATIONS:
C     ******** ************
C
C       *** NONE ***
C
C     PARAMETERS:
C     **********
C
C       PRSDB   -> PRESSURE IN DECIBARS
C       RHO     -> INSITU DENSITY (1000+SIGMAZ) IN Kg/M**3
C       ALPH    <- SPECIFIC VOLUME IN M**3/Kg
C       DELTA   <- SPECIFIC VOLUME ANOMALY IN M**3/Kg
C
        REAL PRSDB,RHO,ALPH,DELTA
C
C     VARIABLES:
C     *********
C
        REAL RHO035
C
C     CONSTANTS:
C     *********
C
C       *** NONE ***
C
C     STATEMENT FUNCTIONS:
C     ********* *********
C
C       *** NONE ***
C
C     DYNAMIC INITIALIZATION STATEMENTS:
C     ******* ************** **********
C
C       *** NONE ***
C
C     CODE:
C     ****
C
C     /* CALCULATE SPECIFIC VOLUME, SP VOL ANOMOLY */
C
      ALPH  = 1.0/RHO
      CALL SIGMP(PRSDB,PRSDB,0.0,35.0,RHO035)
C       /* RHO(P,0,35) */
C
      DELTA  = ALPH -1.0/(RHO035+1000.0)
C       /* SPECIFIC VOLUME ANOMOLY */
C
C     /* RETURN */
C
      RETURN
C
C     END ALPHA
C
      END
