      SUBROUTINE SIGMP(REFPRS,PRSDB,TEMP,SALTY,SIGMA)
C
C     TITLE:
C     *****
C
C       SIGMP  -- CALCULATE DENSITY USING INTERNATIONAL EQUATION OF
C                 STATE
C
C     PURPOSE:
C     *******
C
C       TO CALCULATE A DENSITY SIGMA FOR AN ARBITRARY REFERENCE PRESSURE
C
C     EXTERNAL REFERENCES:
C     ******** **********
C
C       POTMP  -- CALCULATE POTENTIAL TEMPERATURE (BRYDEN)
C       RHO    -- CALCULATE DENSITY (IES)
C
C     PARAMETERS:
C     **********
C
C       REFPRS -> REFERENCE PRESSURE IN DECIBARS
C       PRSDB  -> INSITU PRESSURE IN DECIBARS
C       TEMP   -> INSITU TEMPERATURE IN CELSIUS DEGREES
C       SALTY  -> INSITU SALINITY PSS 78
C       SIGMA  <- Kg/M*3 - 1000.0
C
        REAL REFPRS,PRSDB,TEMP,SALTY,SIGMA
C
C     VARIABLES:
C     *********
C
        REAL POTEMP,RHOSTP
C
C     CODE:
C     ****
C
C     /* CALCULATE POTENTIAL TEMPERATURE */
C
      CALL POTMP(PRSDB,TEMP,SALTY,REFPRS,POTEMP)
C
C     /* CALCULATE RHO */
C
      CALL RHO(REFPRS,PRSDB,POTEMP,SALTY,RHOSTP)
C
      SIGMA  = RHOSTP - 1000.
C       /* DENSITY IN Kg/M**3 - 1000. */
C
C     /* RETURN */
C
  999 CONTINUE
      RETURN
C
C     END SIGMP
C
      END
